yakumo.glance.v2

Package yakumo :: Package glance :: Package v2 |
[hide private]
[frames] | no frames]

# Package v2

source code

Sub client class for Glance API v2

Submodules | [hide private]
yakumo.glance.v2.image: Resource class and its manager for images in Image V2 API yakumo.glance.v2.image_member: Resource class and its manager for image members in Image V2 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.glance.v2``'``